@@ -14,7 +14,6 @@
 EnvironmentsManager::EnvironmentsManager()
 {
     createGeneralEnvironments();
-    createKeyringEnvironments();
     createDBusEnvironments();
 }
 
@@ -74,14 +73,21 @@ void EnvironmentsManager::init()
 
 void EnvironmentsManager::createGeneralEnvironments()
 {
+    QByteArray sessionType = qgetenv("XDG_SESSION_TYPE");
     double scaleFactor = 1.0;
-    QDBusInterface dbusInterface("org.deepin.dde.XSettings1", "/org/deepin/dde/XSettings1",
+
+    if (sessionType == "x11") {
+        QDBusInterface dbusInterface("org.deepin.dde.XSettings1", "/org/deepin/dde/XSettings1",
         "org.deepin.dde.XSettings1", QDBusConnection::sessionBus());
-    if (dbusInterface.isValid()) {
-        QDBusReply<double> scaleFactorReply = dbusInterface.call("GetScaleFactor");
-        if (scaleFactorReply.isValid()) {
-            scaleFactor = scaleFactorReply.value();
+        if (dbusInterface.isValid()) {
+            QDBusReply<double> scaleFactorReply = dbusInterface.call("GetScaleFactor");
+            if (scaleFactorReply.isValid()) {
+                scaleFactor = scaleFactorReply.value();
+            }
         }
+    } else {
+        // TODO: wayland环境下在这里通过xsettings获取是不合理的，此时xsettings服务还没有启动，并且也无法启动（没有DISPLAY，xwayland此时没有启动）
+        // 且 wayland 此时也无法连接，无法通过协议获取，后续考虑其他方式获取，这里仅影响双击时两次点击坐标的冗余量的设置
     }
 
     auto envs = QProcessEnvironment::systemEnvironment();
@@ -95,7 +101,6 @@ void EnvironmentsManager::createGeneralEnvironments()
     m_envMap.insert("XDG_CURRENT_DESKTOP", "DDE");
     m_envMap.insert("QT_DBL_CLICK_DIST", QString::number(15 * scaleFactor));
 
-    QByteArray sessionType = qgetenv("XDG_SESSION_TYPE");
     if (sessionType == "x11") {
         m_envMap.insert("QT_QPA_PLATFORM", "dxcb;xcb");
     } else if (sessionType == "wayland") {
@@ -107,23 +112,6 @@ void EnvironmentsManager::createGeneralEnvironments()
 
 }
 
-void EnvironmentsManager::createKeyringEnvironments()
-{
-    // man gnome-keyring-daemon:
-    // The daemon will print out various environment variables which should be set
-    // in the user's environment, in order to interact with the daemon.
-    EXEC_COMMAND("/usr/bin/gnome-keyring-daemon", QStringList() << "--start" << "--components=secrets,pkcs11,ssh");
-    const QByteArray &output = p.readAllStandardOutput();
-    QByteArrayList envList = output.split('\n');
-    for (auto env : envList) {
-        auto list = env.split('=');
-        if (list.size() != 2)
-            continue;
-
-        m_envMap.insert(list.at(0), list.at(1));
-    }
-}
-
 void EnvironmentsManager::createDBusEnvironments()
 {
     QByteArrayList additionalEnvs = {"LANG", "LANGUAGE"};
